==> selene-1.0.2-py3-none-any.whl: selene/support/conditions/be.py <==
# MIT License
#
# Copyright (c) 2015-2019 Iakiv Kramarenko
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from selene import conditions


# *** Condition builders ***


def not_(condition_to_be_inverted):
    return conditions.not_(condition_to_be_inverted)


# *** SeleneElement conditions ***


visible = conditions.visible
in_dom = conditions.in_dom
enabled = conditions.enabled
existing = conditions.exist
clickable = conditions.clickable
hidden = conditions.hidden
blank = conditions.blank


# *** SeleneCollection conditions ***


empty = conditions.empty


# *** Other conditions ***

or_not_to_be = conditions.or_not_to_be

==> selene-2.0.0a25-py3-none-any.whl: selene/support/conditions/be.py <==
# MIT License
#
# Copyright (c) 2015-2020 Iakiv Kramarenko
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from selene.core import match
from selene.support.conditions import not_  as _not_

not_ = _not_

visible = match.element_is_visible
hidden = match.element_is_hidden
selected = match.element_is_selected

present = match.element_is_present
in_dom = match.element_is_present    # todo: do we need both present and in_dom?
existing = match.element_is_present  # todo: consider deprecating

absent = match.element_is_absent

enabled = match.element_is_enabled
disabled = match.element_is_disabled

clickable = match.element_is_clickable

blank = match.element_is_blank


# --- Deprecated --- #

empty = match.collection_is_empty
